@@ -60,6 +60,10 @@ def getRemoteAddr(headers, whatap_dict):
         header_val = headers.get(conf.trace_http_client_ip_header_key)
         if header_val:
             return header_val.split(',')[0].strip()
+    x_forwarded_for = headers.get("x-forwarded-for")
+    if x_forwarded_for:
+        x_forwarded_for = x_forwarded_for.split(',')[0].strip() if ',' in x_forwarded_for else None
+        return x_forwarded_for
     if whatap_dict:
         return whatap_dict.get(_REMOTE_ADDR)
 
@@ -237,7 +241,7 @@ def interceptor(fn, dependant, *args, **kwargs):
 async def interceptor_async(fn, dependant, *args, **kwargs):
     if not hasattr(dependant, _WHATAP_DICT):
         return await fn(*args, **kwargs)
-
+    
     ctx = TraceContextManager.getLocalContext()
     
     ctx.service_name = dependant.path
@@ -284,7 +288,7 @@ async def interceptor_async(fn, dependant, *args, **kwargs):
             return await fn(*args, **kwargs)
     except Exception as e:
         pass
-
+    
     start_interceptor(ctx)
     
     try:
@@ -387,7 +391,7 @@ def instrument_util(module):
                             'query_params': copy(request.query_params),
                         })
             ret = await fn(*args, **kwargs)            
-            if len(ret) >= 4:
+            if hasattr(ret, '__len__') and len(ret) >= 4:
                 response = ret[3]
                 whatap_dict[_RESPONSE] = response
             
