@@ -307,8 +307,12 @@ def interceptor_step_error(e, ctx=None):
 def interceptor_httpc_request(fn, httpc_url, *args, **kwargs):
     ctx = TraceContextManager.getLocalContext()
     if not ctx or ctx.active_httpc_hash:
-        return fn(*args, **kwargs)
-
+        try:
+            return fn(*args, **kwargs)
+        except Exception as e:
+            interceptor_step_error(e, ctx=ctx)
+        finally:    
+            return
     param = None
     method = None
     if httpc_url.find('?') > -1:
@@ -365,7 +369,7 @@ def interceptor_sock_connect(fn, *args, **kwargs):
 
 def interceptor_db_con(fn, db_type, *args, **kwargs):
     ctx = TraceContextManager.getLocalContext()
-    if ctx.db_opening:
+    if not ctx:
         return fn(*args, **kwargs)
 
     start_time = DateUtil.nowSystem()
@@ -443,7 +447,7 @@ def interceptor_db_execute(fn, *args, **kwargs):
     except Exception as e:
         query = args[1]
 
-    if not query or ctx.active_sqlhash:
+    if not query:
         return fn(*args, **kwargs)
 
     start_time = DateUtil.nowSystem()
@@ -474,19 +478,26 @@ def interceptor_db_close(fn, *args, **kwargs):
     ctx.db_opening = False
 
     if not conf.profile_dbc_close:
-        return fn(*args, **kwargs)
-
+        try:
+            return fn(*args, **kwargs)
+        except Exception as e:
+            interceptor_step_error(e)
+        finally:
+            return
     start_time = DateUtil.nowSystem()
     ctx.start_time = start_time
-
-    callback = fn(*args, **kwargs)
-
-    text = 'DB: Close Connection.'
-    datas = [' ', ' ', text]
-    ctx.elapsed = DateUtil.nowSystem() - start_time
-    async_sender.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
-    return callback
-
+    
+    try:
+        callback = fn(*args, **kwargs)
+        return callback
+    except Exception as e:
+        interceptor_step_error(e)
+    finally:
+        text = 'DB: Close Connection.'
+        datas = [' ', ' ', text]
+        ctx.elapsed = DateUtil.nowSystem() - start_time
+        async_sender.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
+    
 
 check_seq = 1
 
